@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -148,32 +148,27 @@ public class CXFActivator extends HousekeepingActivator {
                         }
                         return config;
                     }
-
-                    private Bus registerCxfServlet(String alias, HttpService httpService, Dictionary<String, Object> config, Bus buzz) throws ServletException, NamespaceException {
+    
+                    private CXFOsgiServlet registerCxfServlet(String alias, HttpService httpService, Dictionary<String, Object> config) throws ServletException, NamespaceException {
                         // Create a register Servlet
                         CXFOsgiServlet cxfServlet = new CXFOsgiServlet();
                         httpService.registerServlet(alias, cxfServlet, config, null);
                         LOG.info("Registered CXF Servlet under: {}", alias2);
-
+    
                         // Get CXF bus
-                        Bus bus;
-                        if (buzz == null) {
-                            Bus createdBus = cxfServlet.getBus();
-                            if (null == createdBus) {
-                                createdBus = BusFactory.newInstance().createBus();
-                                cxfServlet.setBus(createdBus);
-                            }
-                            bus = createdBus;
-                        } else {
-                            cxfServlet.setBus(buzz);
-                            bus = buzz;
+                        Bus createdBus = cxfServlet.getBus();
+                        if (null == createdBus) {
+                            createdBus = BusFactory.newInstance().createBus();
+                            cxfServlet.setBus(createdBus);
                         }
-
+                        Bus bus = createdBus;
+    
                         // Add interceptors here
                         bus.getInInterceptors().add(new TransformGenericElementsInterceptor());
                         bus.getInInterceptors().add(new DropDeprecatedElementsInterceptor(ImmutableSet.of("clusterWeight")));
                         bus.setExtension(new ServletDestinationFactory(), HttpDestinationFactory.class);
-                        return bus;
+                        BusFactory.setDefaultBus(bus);
+                        return cxfServlet;
                     }
 
                     @Override
@@ -190,22 +185,21 @@ public class CXFActivator extends HousekeepingActivator {
                             Dictionary<String, Object> config = buildConfig(baseAddress, configService);
 
                             // Register CXF Serlvet for different aliases
-                            Bus bus = registerCxfServlet(alias, httpService, config, null);
-                            registerCxfServlet(alias2, httpService, config, bus);
+                            CXFOsgiServlet servlet = registerCxfServlet(alias, httpService, config);
+                            httpService.registerServlet(alias2, servlet, config, null);
                             if (null != baseAddress) {
                                 try {
                                     URL url = new URL(baseAddress);
                                     String servletAlias = url.getPath();
                                     if (!alias.equals(servletAlias) && !alias2.equals(servletAlias)) {
                                         alias3 = servletAlias;
-                                        registerCxfServlet(servletAlias, httpService, config, bus);
+                                        httpService.registerServlet(alias3, servlet, config, null);
                                     }
                                 } catch (MalformedURLException e) {
                                     throw new IllegalStateException("Invalid URL specified in property \"com.openexchange.soap.cxf.baseAddress\": \"" + baseAddress + "\"", e);
                                 }
                             }
                             // Apply as default bus
-                            BusFactory.setDefaultBus(bus);
                             servletRegistered = true;
 
                             // Initialize Webservice collector
